## Release Notes for 1.3 RC 1

Released on 18 April 2021

This is a release candidate of 1.3. The primary feature of release 1.3 is the addition of internationalisation (i18n) of novelWriter. The release introduces support for Portuguese, French, and Norwegian in addition to the default English.

There have been no major changes since the release of 1.3 Beta 1, but the bugfixes and improvements from version 1.2.3 have been included.

See also the Releases page.